@@ -30,7 +30,7 @@ from The Open Group.
 
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2009 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2011 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
 /* NXAUTH, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
@@ -513,7 +513,7 @@ get_displayname_auth(char *displayname, Xauth *auth)
      */
 
     if (strncmp (displayname, "/tmp/launch", 11) == 0)
-      displayname = strrchr(displayname, '/') + 1;
+      displayname = strrchr(displayname, ':');
 
     #endif
 
